import React, { useRef,useState } from 'react'
import moment from 'moment';
import { DatePicker, Button } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable'
import { getApplicationList } from '@/services/application'
import { history } from 'umi';


const { RangePicker } = DatePicker;

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};

export default (props) => {
  const actionRef = useRef();  
  const [applyStart, setStart] = useState()
  const [applyEnd, setEnd] = useState()
  const goDetail = (id) => {
    history.push(`applicationList/detail.jsx?id=${id}`);
  }

  const handelChange = (date, dateStrings) => {
    setStart(dateStrings[0])
    setEnd(dateStrings[1])
  }

  const handleReset = () => {
    setStart()
    setEnd()
  }
  const columns = [
    {
      title: '犬主',
      dataIndex: 'personName',
      key: 'personName',
      search: true,
    },
    {
      title: '是否企业',
      dataIndex: 'isOrg',
      key: 'isOrg',
      search: true,
      hideInTable:true,
      render: (_, record) => {
        return record.isOrg
          ? '企业':'个人'
      },
      valueType: 'select',
      valueEnum: {
        true: { text: '企业' },
        false: { text: '个人' },
      },
    },
    {
      title: '企业名称',
      dataIndex: 'orgName',
      key: 'orgName',
      search: true,
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
      search: true,
    },
    {
      title: '犬名',
      dataIndex: 'petName',
      key: 'petName',
      search: false,
    },
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      width:160,
      render: (t) => formatterTime(t),
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' onChange={handelChange} />
    },
    {
      title: '申请类型',
      dataIndex: 'applyType',
      key: 'applyType',
      search: true,
      render: (_, record) => {
        return record.applyType === 'first'
          ? '办证'
          : record.applyType === 'reissue'
            ? '补办'
            : record.applyType === 'renewal'
              ? '续期' : ''
      },
      valueType: 'select',
      valueEnum: {
        'first': { text: '办证' },
        'reissue': { text: '补办' },
        'renewal': { text: '续期' },
      },
    },
    {
      title: '支付状态',
      dataIndex: 'payStatus',
      key: 'payStatus',
      search: true,//已支付 待支付
      render: (_, record) => {
        return record.payStatus === 0
          ? '待支付'
          : record.payStatus === 1
            ? '支付中'
            : record.payStatus === 2
              ? '已支付' 
              : record.payStatus === 3
              ? '已退款' : ''
      },
      valueType: 'select',
      valueEnum: {
        0: { text: '待支付' },
        2: { text: '已支付' },
        3: { text: '已退款' },
      },
    },
    {
      title: '审核状态',
      dataIndex: 'verifyStatus',
      key: 'verifyStatus',
      search: true,
      render: (_, record) => {
        return record.verifyStatus === 0
          ? '待审核'
          : record.verifyStatus === 1
            ? '审核通过'
            : record.verifyStatus === 2
              ? '审核驳回' : ''
      },
      valueType: 'select',
      valueEnum: {
        0: { text: '待审核' },
        1: { text: '审核通过' },
        2: { text: '审核驳回' },
      },
    },
    {
      title: '制证状态',
      dataIndex: 'makeStatus',
      key: 'makeStatus',
      search: false, 
      render: (_, record) => {
        return record.makeStatus === 0
          ? '待发放'
          : record.makeStatus === 1
            ? '已发放' : ''
      },
    },
    {
      title: '操作',
      valueType: 'option',
      width: 160,
      render: (_, record) => [
        <Button key={1} style={{ padding: 0 }} type="link"
          onClick={() => goDetail(record.applyId)}>
          详情
        </Button>
      ],
    },
  ]


  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={actionRef}
        columns={columns}
        params={{ applyStart, applyEnd }}
        request={getApplicationList}
        options={false}
        onReset={handleReset}
        rowKey="applyId"
      />
    </PageHeaderWrapper>
  )
}
