import React, { useState, useEffect } from 'react';
import { Card, Form, Button, Image } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getCardDetail, getCardQRCode } from '@/services/card'
import { history } from 'umi';

const FormItem = Form.Item;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
const goBack = () => {
  history.goBack();
};
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [card, setCard] = useState({});
  const [qrcode, setQrcode] = useState();
  useEffect(() => {
    getCardDetail(id).then((res) => {
      setCard(res)
      getCardQRCode(res.cardNo).then((res2) => {
        setQrcode(res2.qrImage)
      })
    }).catch((err) => {
      console.log(err.message)
    });
  }, [id])
  return (
    <PageHeaderWrapper    >
      <Card>
        <Form {...formItemLayout}>
          <FormItem label="证件号">
            {card?.cardNo}
          </FormItem>
          <FormItem label="证件状态">
            {
              card?.status == 1 ? '正常' :
                card?.status == 2 ? '挂失' :
                  card?.status == 3 ? '过期' : ''
            }
          </FormItem>
          <FormItem label="犬主">
            {card?.personName}
          </FormItem>
          {
            card?.isOrg &&
            <FormItem label="企业">
              {card?.orgName}
            </FormItem>
          }
          <FormItem label="电话">
            {card?.phone}
          </FormItem>
          <FormItem label="犬名">
            {card?.petName}
          </FormItem>
          <FormItem label="性别">
            {
              card?.petSex == 1 ? '雄' :
                card?.petSex == 2 ? '雌' : '未说明性别'
            }
          </FormItem>
          <FormItem label="犬种">
            {card?.petType}
          </FormItem>
          <FormItem label="毛色">
            {card?.petColor}
          </FormItem>
          <FormItem label="照片">
            <Image src={card?.petImg1} width={100} />
          </FormItem>
          <FormItem label="养狗地址">
            {card?.address}
          </FormItem>
          <FormItem label="狗证有效期">
            {card?.startDate + '~' + card?.expireDate}
          </FormItem>
          {
            card?.criminalInfo &&
            <FormItem label="伤人信息">
              <Image src={card.criminalInfo} width={100} />
            </FormItem>
          }
          {
            card?.penaltyInfo &&
            <FormItem label="处罚信息">
              <Image src={card.penaltyInfo} width={100} />
            </FormItem>
          }
          <FormItem label="小程序码">
            {
              qrcode && <Image src={qrcode} width={100} />
            }
          </FormItem>
          <FormItem label=" " colon={false}>
            <Button type="default" onClick={() => goBack()}>
              返回
            </Button>
          </FormItem>
        </Form>
      </Card>
    </PageHeaderWrapper>
  );
};
